@@ -6,15 +6,15 @@ def create(_):
 
     log.setLevel(logging.DEBUG)
     store = LDAPStore()
-    username = raw_input('username: ')
+    username = input('username: ')
 
     while username:
       password = getpass.getpass('password: ')
       user = store.login(username, dict(password=password))
       if user:
-        print('OK {u.id} name:{u.name} roles:{u.roles} dn:{u.dn} {u.info} {u.groups}'.format(u=user))
+        print(('OK {u.id} name:{u.name} roles:{u.roles} dn:{u.dn} {u.info} {u.groups}'.format(u=user)))
       else:
         print('ERROR')
-      username = raw_input('another username: ')
+      username = input('another username: ')
 
   return lambda _: _loop
